@@ -60,7 +60,7 @@ class FancyPlotterLabel : public QLabel {
         textMargin = 0;
         setLayoutDirection(Qt::LeftToRight); //We do this because we organise the strings ourselves.. is this going to muck it up though for RTL languages?
     }
-    ~FancyPlotterLabel() Q_DECL_OVERRIDE {
+    ~FancyPlotterLabel() override {
     }
     void setLabel(const QString &name, const QColor &color) {
         labelName = name;
@@ -80,7 +80,7 @@ class FancyPlotterLabel : public QLabel {
         resizeEvent(nullptr);
         update();
     }
-    void resizeEvent( QResizeEvent * ) Q_DECL_OVERRIDE {
+    void resizeEvent( QResizeEvent * ) override {
         QFontMetrics fm = fontMetrics();
 
         if(valueText.isEmpty()) {
@@ -397,7 +397,7 @@ void FancyPlotter::applyStyle()
     font.setPointSize(KSGRD::Style->fontSize() );
     mPlotter->setFont( font );
     for ( int i = 0; i < mPlotter->numBeams() &&
-            (unsigned int)i < KSGRD::Style->numSensorColors(); ++i ) {
+            i < KSGRD::Style->numSensorColors(); ++i ) {
         setBeamColor(i, KSGRD::Style->sensorColor(i));
     }
 
@@ -527,7 +527,7 @@ void FancyPlotter::setTooltip()
                 showingSummationGroup = true;
                 neednewline = false;
             } else if (showingSummationGroup) {
-                //When a summation group has finished, seperate the next sensor with a newline
+                //When a summation group has finished, separate the next sensor with a newline
                 showingSummationGroup = false;
                 tooltip += QLatin1String("<br>");
             }
